﻿using Microsoft.Extensions.Logging;
using SushiBarContracts.BindingModel;
using SushiBarContracts.BusinessLogicsContracts;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace SushiBarView
{
    public partial class FormClients : Form
    {
        private readonly ILogger _logger;
        private readonly IClientLogic _clientLogic;

        public FormClients(ILogger<FormClients> logger, IClientLogic logic)
        {
            _logger = logger;
            _clientLogic = logic;
            InitializeComponent();
        }

        private void FormClients_Load(object sender, EventArgs e)
        {
            LoadData();
        }

        private void LoadData()
        {
            try
            {
                var list = _clientLogic.ReadList(null);
                if (list != null)
                {
                    dataGridView.DataSource = list;
                    dataGridView.Columns["Id"].Visible = false;
                    dataGridView.Columns["ClientFIO"].AutoSizeMode = DataGridViewAutoSizeColumnMode.Fill;
                    _logger.LogInformation("Клиенты успешно загружены");
                }
            }
            catch (Exception ex)
            {
                _logger.LogError(ex.Message, "Ошибка загрузки клиентов");
                MessageBox.Show(ex.Message, "Ошибка загрузки клиентов");
            }
        }

        private void buttonDelete_Click(object sender, EventArgs e)
        {
            if (dataGridView.SelectedRows.Count == 1)
            {
                if (MessageBox.Show("Вы серьезно хотите удалить клиента? :_) та за что...", "Вопрос",
                    MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.Yes)
                {
                    try
                    {
                        int id = Convert.ToInt32(dataGridView.SelectedRows[0].Cells["Id"].Value);
                        _logger.LogInformation($"Удален клиент под номером {id}");

                        if (!_clientLogic.Delete(new ClientBindingModel
                        {
                            Id = id
                        }))
                        {
                            throw new Exception("Ошибка при удалении. Дополнительная информация в логах.");
                        }
                        LoadData();
                    }
                    catch (Exception ex)
                    {
                        MessageBox.Show(ex.Message, "Не удалось удалить клиента");
                        _logger.LogError(ex.Message, "Не удалось удалить клиента");
                    }
                }
            }
        }

        private void buttonRefresh_Click(object sender, EventArgs e)
        {
            LoadData();
        }
    }
}
